#!/usr/bin/env python

#-----------------------------------------------------------------------
# authorsearchprep.py
# Author: Bob Dondero
#-----------------------------------------------------------------------

import sys
import contextlib
import sqlite3

#-----------------------------------------------------------------------

DATABASE_URL = 'file:bookstore.sqlite?mode=ro'

def main():

    if len(sys.argv) != 2:
        print('Usage: python ' + sys.argv[0] + ' author',
            file=sys.stderr)
        sys.exit(1)

    author = sys.argv[1]

    try:
        with sqlite3.connect(DATABASE_URL, isolation_level=None,
            uri=True) as connection:

            with contextlib.closing(connection.cursor()) as cursor:

                # Create a prepared statement and substitute values.
                stmt_str = "SELECT books.isbn, title, quantity "
                stmt_str += "FROM books, authors "
                stmt_str += "WHERE books.isbn = authors.isbn "
                stmt_str += "AND author = ?"
                cursor.execute(stmt_str, [author])

                table = cursor.fetchall()
                for row in table:
                    print('ISBN:', row[0])
                    print('Title:', row[1])
                    print('Quantity:', row[2])
                    print()

    except Exception as ex:
        print(ex, file=sys.stderr)
        sys.exit(1)

#-----------------------------------------------------------------------

if __name__ == '__main__':
    main()
