#!/usr/bin/env python

#-----------------------------------------------------------------------
# purchase.py
# Author: Bob Dondero
#-----------------------------------------------------------------------

import sys
import contextlib
import sqlite3

#-----------------------------------------------------------------------

DATABASE_URL = 'file:bookstore.sqlite?mode=rw'

def main():

    if len(sys.argv) != 3:
        print('Usage: python ' + sys.argv[0] + ' isbn custid',
            file=sys.stderr)
        sys.exit(1)

    isbn = sys.argv[1]
    custid = sys.argv[2]

    try:
        with sqlite3.connect(DATABASE_URL, isolation_level=None,
            uri=True) as connection:

            with contextlib.closing(connection.cursor()) as cursor:

                cursor.execute('BEGIN')

                stmt_str = "UPDATE orders SET quantity = quantity+1 "
                stmt_str += "WHERE isbn = ? AND custid = ?"
                cursor.execute(stmt_str, [isbn, custid])

                stmt_str = "UPDATE books SET quantity = quantity-1 "
                stmt_str += "WHERE isbn = ?"
                cursor.execute(stmt_str, [isbn])

                cursor.execute('COMMIT')
                print('Transaction committed.')

    except Exception as ex:
        print(ex, file=sys.stderr)
        sys.exit(1)

#-----------------------------------------------------------------------

if __name__ == '__main__':
    main()
