#!/usr/bin/env python

#-----------------------------------------------------------------------
# recovery.py
# Author: Bob Dondero
#-----------------------------------------------------------------------

import sys
import random
import contextlib
import sqlite3

#-----------------------------------------------------------------------

DATABASE_URL = 'file:bookstore.sqlite?mode=rw'

def main():

    if len(sys.argv) != 1:
        print('Usage: python ' + sys.argv[0], file=sys.stderr)
        sys.exit(1)

    try:
        with sqlite3.connect(DATABASE_URL, isolation_level=None,
            uri=True) as connection:

            with contextlib.closing(connection.cursor()) as cursor:

                for i in range(20):

                    cursor.execute('BEGIN')

                    stmt_str = "UPDATE orders "
                    stmt_str += "SET quantity = quantity+1 "
                    stmt_str += "WHERE isbn = '123' "
                    stmt_str += "AND custid = '222'"
                    cursor.execute(stmt_str)

                    # Simulate a HW/SW failure occurring randomly,
                    # on average every 5th time through the loop.
                    if random.randrange(5) == 0:
                        print('Simulated failure with i = %d' % i)
                        cursor.execute('ROLLBACK')
                        print('Transaction %d rolled back.' % i)
                        continue

                    stmt_str = "UPDATE books "
                    stmt_str += "SET quantity = quantity-1 "
                    stmt_str += "WHERE isbn = '123'"
                    cursor.execute(stmt_str)

                    cursor.execute('COMMIT')
                    print('Transaction %d committed.' % i)

    except Exception as ex:
        print(ex, file=sys.stderr)
        sys.exit(1)

#-----------------------------------------------------------------------

if __name__ == '__main__':
    main()
